featuremgmt/featuremgr/src/serverexe/featmgrsecuritypolicy.h
branchRCL_3
changeset 8 fa9941cf3867
parent 0 08ec8eefde2f
--- a/featuremgmt/featuremgr/src/serverexe/featmgrsecuritypolicy.h	Sat Feb 20 00:33:55 2010 +0200
+++ b/featuremgmt/featuremgr/src/serverexe/featmgrsecuritypolicy.h	Fri Mar 12 15:51:02 2010 +0200
@@ -40,8 +40,8 @@
 const TInt KFeatMgrPlatSecRanges[KFeatMgrPlatSecRangeCount] =
     {
     0,  // IPC 0-7 Always passed
-    8,  // IPC 8-13 WriteDeviceData
-    16  // IPC Not supported 16 ->
+    8,  // IPC 8-19 WriteDeviceData
+    20  // IPC Not supported: 20 = 16 messages + 4 "resource check" messages
     };
 
 
@@ -51,8 +51,8 @@
 const TUint8 KFeatMgrPlatSecElementsIndex[KFeatMgrPlatSecRangeCount] =
     {
     CPolicyServer::EAlwaysPass,             // IPC 0-3
-    0,                                      // IPC 8-13
-    CPolicyServer::ENotSupported            // IPC 16 -> 
+    0,                                      // IPC 8-19
+    CPolicyServer::ENotSupported            // IPC 20 -> 
     };
 
 #else
@@ -69,8 +69,8 @@
 const TInt KFeatMgrPlatSecRanges[KFeatMgrPlatSecRangeCount] =
     {
     0,   // IPC 0-9 Always passed
-    10,  // IPC 10-15 WriteDeviceData
-    18   // IPC Not supported 18 ->
+    10,  // IPC 10-21 WriteDeviceData
+    22   // IPC Not supported 22 ->
     };
 /**
  * IPC segments and their capability requirements
@@ -78,8 +78,8 @@
 const TUint8 KFeatMgrPlatSecElementsIndex[KFeatMgrPlatSecRangeCount] =
     {
     CPolicyServer::EAlwaysPass,             // IPC 0-3
-    0,                                      // IPC 10-15
-    CPolicyServer::ENotSupported            // IPC 18 ->
+    0,                                      // IPC 10-21
+    CPolicyServer::ENotSupported            // IPC 22 ->
     };
 
 #endif